@@ -2,6 +2,7 @@ package Math::Tail;
 use warnings;
 use strict;
 use Getopt::Long;
+use Pod::Usage;
 
 sub _Error {
   my $parser = shift;
@@ -37,7 +38,8 @@ sub make_lexer {
 
       m{\G([0-9]+(?:\.[0-9]+)?)}gc   and return ('NUM', [$1, $beginline]);
       m{\G([A-Za-z][A-Za-z0-9_]*)}gc and return ('VAR', [$1, $beginline]);
-      m{\G\n}gc                      and do { $lineno++; return ("\n", ["\n", $beginline]) };
+      m{\G\n}gc                      and 
+                      do { $lineno++; return ("\n", ["\n", $beginline]) };
       m{\G(.)}gc                     and return ($1,    [$1, $beginline]);
 
       return('',undef);
@@ -78,11 +80,15 @@ sub main {
 
   my $debug = 0;
   my $file = '';
+  my $help;
   my $result = GetOptions (
     "debug!" => \$debug,  
     "file=s" => \$file,
+    "help"   => \$help,
   );
 
+  pod2usage() if $help;
+
   $debug = 0x1F if $debug;
   $file = shift if !$file && @ARGV; 
 
@@ -102,3 +108,4 @@ sub semantic_error {
 }
 
 1;
+
